/*
 * Copyright (C) 2006 Joe Walnes.
 * Copyright (C) 2007, 2008 XStream Committers.
 * All rights reserved.
 *
 * The software in this package is published under the terms of the BSD
 * style license a copy of which has been included with this distribution in
 * the LICENSE.txt file.
 * 
 * Created on 13. June 2006 by Guilherme Silveira
 */
package com.thoughtworks.xstream.persistence;

/**
 * A key to filename and vice-versa strategy interface.
 * 
 * @author Guilherme Silveira
 * @deprecated since 1.3.1, use {@link PersistenceStrategy} instead
 */
public interface StreamStrategy extends PersistenceStrategy {
}